
.. .. image:: https://readthedocs.org/projects/acore-server-monitoring-core/badge/?version=latest
    :target: https://acore-server-monitoring-core.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/acore_server_monitoring_core-project/actions/workflows/main.yml/badge.svg
    :target: https://github.com/MacHu-GWU/acore_server_monitoring_core-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/acore_server_monitoring_core-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/acore_server_monitoring_core-project

.. image:: https://img.shields.io/pypi/v/acore-server-monitoring-core.svg
    :target: https://pypi.python.org/pypi/acore-server-monitoring-core

.. image:: https://img.shields.io/pypi/l/acore-server-monitoring-core.svg
    :target: https://pypi.python.org/pypi/acore-server-monitoring-core

.. image:: https://img.shields.io/pypi/pyversions/acore-server-monitoring-core.svg
    :target: https://pypi.python.org/pypi/acore-server-monitoring-core

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/acore_server_monitoring_core-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/acore_server_monitoring_core-project

------

.. .. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://acore-server-monitoring-core.readthedocs.io/en/latest/

.. .. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://acore-server-monitoring-core.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/acore_server_monitoring_core-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/acore_server_monitoring_core-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/acore_server_monitoring_core-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/acore-server-monitoring-core#files


Welcome to ``acore_server_monitoring_core`` Documentation
==============================================================================
.. .. image:: https://acore-server-monitor-core.readthedocs.io/en/latest/_static/acore_server_monitoring_core-logo.png
    :target: https://acore-server-monitor-core.readthedocs.io/en/latest/

This project works with `acore_server_monitoring_measurement <https://github.com/MacHu-GWU/acore_server_monitoring_measurement-project>`_, `acore_server_monitoring_analytics <https://github.com/MacHu-GWU/acore_server_monitoring_analytics-project>`_ together, provides server monitoring capabilities. This project is the core of the other two projects.


.. _install:

Install
------------------------------------------------------------------------------

``acore_server_monitoring_core`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install acore-server-monitoring-core

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade acore-server-monitoring-core
